"""

Revision ID: 14b821135552
Revises: 65662e214031
Create Date: 2025-11-13 12:33:13.970721

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import sqlite
import sqlmodel

# revision identifiers, used by Alembic.
revision: str = "14b821135552"
down_revision: Union[str, None] = "65662e214031"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "portfolio",
        sa.Column("name", sqlmodel.sql.sqltypes.AutoString(), nullable=False),
        sa.Column("current_assets", sa.JSON(), nullable=True),
        sa.Column("new_assets", sa.JSON(), nullable=True),
        sa.Column("total_value", sa.Float(), nullable=True),
        sa.PrimaryKeyConstraint("name"),
    )

    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###

    op.drop_table("portfolio")
    # ### end Alembic commands ###
